"""
App init
"""

# Django
from django.utils.translation import gettext_lazy as _

__version__ = "2.12.1"
__title__ = _("Ship Replacement")

__package_name__ = "aa-srp"
__app_name__ = "aasrp"
__app_name_verbose__ = "AA SRP"
__app_name_useragent__ = "AA-SRP"

__github_url__ = f"https://github.com/ppfeufer/{__package_name__}"
