# Generated by Django 4.0.10 on 2023-03-06 09:09

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aasrp", "0008_aasrprequestcomment_new_status_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="FleetType",
            fields=[
                ("id", models.AutoField(primary_key=True, serialize=False)),
                (
                    "name",
                    models.CharField(
                        help_text="Descriptive name of your fleet type", max_length=254
                    ),
                ),
                (
                    "is_enabled",
                    models.BooleanField(
                        db_index=True,
                        default=True,
                        help_text="Whether this fleet type is active or not",
                    ),
                ),
            ],
            options={
                "verbose_name": "SRP Link Fleet Type",
                "verbose_name_plural": "SRP Link Fleet Types",
                "default_permissions": (),
            },
        ),
        migrations.AddField(
            model_name="aasrplink",
            name="fleet_type",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="The SRP link fleet type, if it's set",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="+",
                to="aasrp.fleettype",
            ),
        ),
    ]
