<li class="nav-item">
    <a href="{{ url }}" class="nav-link py-lg-0">
        <span class="btn btn-{{ btn_modifier }} d-none d-lg-inline-block">
            {{ title }}
        </span>

        <span class="d-inline-block d-lg-none">
            <i class="{{ fa_icon }} me-2"></i>
            {{ title }}
        </span>
    </a>
</li>
