{% load navactive %}

<li class="nav-item" role="presentation">
    <a class="nav-link {{ navactive }}" href="{{ url }}">
        <i class="{{ fa_icon }} fa-fw me-1 d-lg-none"></i>
        {{ title }}
    </a>
</li>
