{% load i18n %}
{% load navactive %}

<!-- SRP links -->
{% if perms.aasrp.manage_srp %}
    {% if request.resolver_match.url_name == "srp_links_all" %}
        {% url 'aasrp:srp_links_all' as url_srp_links %}
        {% translate "SRP links (all)" as l10n_srp_links %}
    {% else %}
        {% url 'aasrp:srp_links' as url_srp_links %}
        {% translate "SRP links (active)" as l10n_srp_links %}
    {% endif %}
{% else %}
    {% url 'aasrp:srp_links' as url_srp_links %}
    {% translate "SRP links" as l10n_srp_links %}
{% endif %}

{% navactive request 'aasrp:srp_links aasrp:srp_links_all' as navactive_srp_links %}
{% include "aasrp/partials/navigation/top-navigation-item.html" with url=url_srp_links navactive=navactive_srp_links title=l10n_srp_links fa_icon="fa-regular fa-money-bill-1" %}

<!-- My SRP requests -->
{% url 'aasrp:own_srp_requests' as url_own_srp_requests %}
{% navactive request 'aasrp:own_srp_requests' as navactive_own_srp_requests %}
{% translate "My SRP requests" as l10n_own_srp_requests %}
{% include "aasrp/partials/navigation/top-navigation-item.html" with url=url_own_srp_requests navactive=navactive_own_srp_requests title=l10n_own_srp_requests fa_icon="fa-solid fa-hand-holding-dollar" %}

<!-- My settings -->
{% url 'aasrp:user_settings' as url_user_settings %}
{% navactive request 'aasrp:user_settings' as navactive_user_settings %}
{% translate "My settings" as l10n_user_settings %}
{% include "aasrp/partials/navigation/top-navigation-item.html" with url=url_user_settings navactive=navactive_user_settings title=l10n_user_settings fa_icon="fa-solid fa-user-cog" %}
