{% load i18n %}

<div class="card card-default">
    <div class="card-header">
        <div class="card-title mb-0">
            {% translate "SRP requests" %}
        </div>
    </div>

    <div class="card-body">
        <div class="table-responsive">
            <table class="table table-striped table-aasrp table-srp-requests table-vertical-middle w-100" id="tab_aasrp_srp_requests">
                <thead>
                    <tr>
                        <th class="w-auto">{% translate "Request time" %}</th>
                        <th class="w-auto">{% translate "Requestor" %}</th>
                        <th class="w-auto">{% translate "Character" %}</th>
                        <th class="w-auto">{% translate "Request code" %}</th>
                        <th class="w-auto">{% translate "Ship" %}</th>
                        <th class="w-auto">{% translate "ISK lost" %}</th>
                        <th class="w-auto">
                            {% translate "SRP payout" %}
                            <i
                                class="fa-solid fa-circle-question fa-fw"
                                data-bs-tooltip="aa-srp"
                                title="{% translate 'Click on the value to edit, Enter to save, ESC to cancel.' %}"
                            ></i>
                        </th>
                        <th class="w-auto">{% translate "Status" %}</th>
                        <th class="w-auto">{% translate "Actions" %}</th>
                        <th class="w-auto"><!-- {% translate "Bulk actions" %} --></th>
                    </tr>
                </thead>

                <tbody></tbody>
            </table>
        </div>
    </div>
</div>
